@@ -257,10 +257,6 @@ func isBinary(data []byte) bool {
 func PrintLanguages(w io.Writer) error {
 	tw := tabwriter.NewWriter(w, 0, 0, 1, ' ', 0)
 
-	if _, err := tw.Write([]byte("NAME\tALIASES\n")); err != nil {
-		return err
-	}
-
 	for _, l := range lexers.List() {
 		cfg := l.Config()
 		if _, err := tw.Write([]byte(fmt.Sprintf("%s\t%s\n", cfg.Name, strings.Join(cfg.Aliases, ", ")))); err != nil {
@@ -271,24 +267,15 @@ func PrintLanguages(w io.Writer) error {
 	return tw.Flush()
 }
 
-func PrintFormats(w io.Writer) error {
-	tw := tabwriter.NewWriter(w, 0, 0, 1, ' ', 0)
-
-	if _, err := tw.Write([]byte("NAME\n")); err != nil {
-		return err
-	}
-
+func PrintFormats(w io.Writer) {
 	for _, f := range formatters.List() {
-		if _, err := tw.Write([]byte(fmt.Sprintf("%s\n", f))); err != nil {
-			return err
-		}
+		fmt.Fprintln(w, f)
 	}
-
-	return tw.Flush()
 }
 
-func PrintThemes(w io.Writer) error {
-	src := `package main
+func PrintThemes(w io.Writer, withColor bool) error {
+	if withColor {
+		src := `package main
 
 import "fmt"
 
@@ -296,33 +283,38 @@ func main() {
 	fmt.Println("hello world")
 }`
 
-	for _, t := range styles.List() {
-		fmt.Fprintf(w, "\x1b[1m%s\x1b[0m\n\n", t)
+		for _, t := range styles.List() {
+			fmt.Fprintf(w, "\x1b[1m%s\x1b[0m\n\n", t)
 
-		g, err := New(&Config{
-			Language: "go",
-			Theme:    t,
-			Format:   "terminal256",
-		})
-		if err != nil {
-			return err
-		}
+			g, err := New(&Config{
+				Language: "go",
+				Theme:    t,
+				Format:   "terminal256",
+			})
+			if err != nil {
+				return err
+			}
 
-		buf := new(bytes.Buffer)
-		if err := g.Print(buf, strings.NewReader(src)); err != nil {
-			return err
-		}
+			buf := new(bytes.Buffer)
+			if err := g.Print(buf, strings.NewReader(src)); err != nil {
+				return err
+			}
 
-		// indent source
-		sc := bufio.NewScanner(buf)
-		for sc.Scan() {
-			if _, err := fmt.Fprintf(w, "\t%s\n", sc.Text()); err != nil {
+			// indent source
+			sc := bufio.NewScanner(buf)
+			for sc.Scan() {
+				if _, err := fmt.Fprintf(w, "\t%s\n", sc.Text()); err != nil {
+					return err
+				}
+			}
+
+			if _, err := fmt.Fprintln(w); err != nil {
 				return err
 			}
 		}
-
-		if _, err := fmt.Fprintln(w); err != nil {
-			return err
+	} else {
+		for _, t := range styles.List() {
+			fmt.Fprintln(w, t)
 		}
 	}
 
